@@ -108,7 +108,8 @@ static union
 {
   int i[4];
   float f[4];
-} av_tmp __attribute__ ((__aligned__ (16)));
+}
+av_tmp __attribute__ ((__aligned__ (16)));
 
 void
 conv_double_short_altivec (double *dest, short *src, int n)
