@@ -46,7 +46,7 @@ static GstElementDetails gst_silence_details = {
   "silence source",
   "Source/Audio",
   "Generates silence",
-  "Zaheer Merali <zaheer@grid9.net>"
+  "Zaheer Abbas Merali <zaheerabbas at merali dot org>"
 };
 
 static GstStaticPadTemplate gst_silence_src_template =
@@ -74,6 +74,7 @@ static void gst_silence_get_property (GObject * object,
     guint prop_id, GValue * value, GParamSpec * pspec);
 static GstElementStateReturn gst_silence_change_state (GstElement * element);
 static void gst_silence_set_clock (GstElement * element, GstClock * clock);
+static gboolean gst_silence_handle_src_event (GstPad * pad, GstEvent * event);
 
 static GstData *gst_silence_get (GstPad * pad);
 static GstPadLinkReturn gst_silence_link (GstPad * pad, const GstCaps * caps);
@@ -102,6 +103,7 @@ gst_silence_get_type (void)
       0,
       (GInstanceInitFunc) gst_silence_init,
     };
+
     silence_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstSilence", &silence_info,
         0);
@@ -155,6 +157,33 @@ gst_silence_set_clock (GstElement * element, GstClock * clock)
   gst_object_replace ((GstObject **) & silence->clock, (GstObject *) clock);
 }
 
+static gboolean
+gst_silence_handle_src_event (GstPad * pad, GstEvent * event)
+{
+  gboolean res = TRUE;
+  GstSilence *silence;
+
+  silence = GST_SILENCE (gst_pad_get_parent (pad));
+
+  switch (GST_EVENT_TYPE (event)) {
+    case GST_EVENT_SEEK:
+      switch (GST_EVENT_SEEK_FORMAT (event)) {
+        case GST_FORMAT_TIME:
+          silence->timestamp = GST_EVENT_SEEK_OFFSET (event);
+          silence->samples =
+              silence->timestamp * silence->frequency / GST_SECOND;
+          silence->offset =
+              silence->timestamp * silence->channels * silence->width;
+        default:
+          res = FALSE;
+      }
+      break;
+    default:
+      res = FALSE;
+  }
+  return res;
+}
+
 static void
 gst_silence_init (GstSilence * silence)
 {
@@ -166,6 +195,7 @@ gst_silence_init (GstSilence * silence)
   gst_pad_set_query_function (silence->srcpad, gst_silence_src_query);
   gst_pad_set_query_type_function (silence->srcpad,
       gst_silence_get_query_types);
+  gst_pad_set_event_function (silence->srcpad, gst_silence_handle_src_event);
   gst_element_add_pad (GST_ELEMENT (silence), silence->srcpad);
 
   /* adding some default values */
@@ -173,7 +203,7 @@ gst_silence_init (GstSilence * silence)
   silence->channels = 2;
   silence->frequency = 44100;
   silence->bytes_per_read = 4096;
-
+  silence->width = 2;           /* 2 bytes */
   silence->timestamp = 0;
   silence->offset = 0;
   silence->samples = 0;
@@ -197,8 +227,11 @@ gst_silence_link (GstPad * pad, const GstCaps * caps)
 
   if (!strcmp (gst_structure_get_name (structure), "audio/x-raw-int")) {
     silence->law = 0;
+    gst_structure_get_int (structure, "width", &silence->width);
+    silence->width /= 8;
   } else {
     silence->law = 1;
+    silence->width = 1;
   }
 
   return GST_PAD_LINK_OK;
@@ -256,6 +289,7 @@ gst_silence_get (GstPad * pad)
   GstSilence *src;
   GstBuffer *buf;
   guint tdiff, samples;
+  gint i;
 
   g_return_val_if_fail (pad != NULL, NULL);
   src = GST_SILENCE (gst_pad_get_parent (pad));
@@ -268,7 +302,7 @@ gst_silence_get (GstPad * pad)
     }
   }
 
-  samples = src->bytes_per_read / (src->channels * (src->law ? 1 : 2));
+  samples = src->bytes_per_read / (src->channels * src->width);
   tdiff = samples * GST_SECOND / src->frequency;
 
   buf = gst_buffer_new_and_alloc (src->bytes_per_read);
@@ -280,7 +314,16 @@ gst_silence_get (GstPad * pad)
   GST_BUFFER_DURATION (buf) = tdiff;
   GST_BUFFER_SIZE (buf) = src->bytes_per_read;
 
-  memset (GST_BUFFER_DATA (buf), src->law ? 0 : 128, src->bytes_per_read);
+  if (src->law || src->width == 1)
+    memset (GST_BUFFER_DATA (buf), src->law ? 0 : 128, src->bytes_per_read);
+  else {
+    /* ok src->width = 2 */
+    gint16 *tmp = (gint16 *) GST_BUFFER_DATA (buf);
+
+    for (i = 0; i < src->bytes_per_read / 2; i++) {
+      tmp[i] = (gint16) 0;
+    }
+  }
 
   src->timestamp += tdiff;
   src->samples += samples;
