@@ -16,13 +16,14 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef __GST_XIMAGESINK_H__
 #define __GST_XIMAGESINK_H__
 
-#include <gst/video/gstvideosink.h>
+#include <gst/video/videosink.h>
 
 #ifdef HAVE_XSHM
+#include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif /* HAVE_XSHM */
@@ -60,22 +61,26 @@ typedef struct _GstXImageSinkClass GstXImageSinkClass;
 /* Global X Context stuff */
 struct _GstXContext {
   Display *disp;
-  
+
   Screen *screen;
   gint screen_num;
-  
+
   Visual *visual;
-  
+
   Window root;
-  
+
   gulong white, black;
-  
+
   gint depth;
   gint bpp;
   gint endianness;
-  
+
+  gint width, height;
+  gint widthmm, heightmm;
+  GValue *par;                  /* calculated pixel aspect ratio */
+
   gboolean use_xshm;
-  
+
   GstCaps *caps;
 };
 
@@ -89,33 +94,47 @@ struct _GstXWindow {
 
 /* XImage stuff */
 struct _GstXImage {
+  /* Reference to the ximagesink we belong to */
+  GstXImageSink *ximagesink;
+
   XImage *ximage;
-  
+
 #ifdef HAVE_XSHM
   XShmSegmentInfo SHMInfo;
 #endif /* HAVE_XSHM */
-  
-  char *data;
+
   gint width, height, size;
 };
 
 struct _GstXImageSink {
   /* Our element stuff */
   GstVideoSink videosink;
-  
+
+  char *display_name;
+
   GstXContext *xcontext;
   GstXWindow *xwindow;
   GstXImage *ximage;
-  
-  gfloat framerate;
+  GstXImage *cur_image;
+
+  gdouble framerate;
   GMutex *x_lock;
-  
+  GMutex *stream_lock;
+
   /* Unused */
   gint pixel_width, pixel_height;
- 
-  GstBufferPool *bufferpool;
+  GValue *par;                  /* object-set pixel aspect ratio */
+
+  GstClockTime time;
+
   GMutex *pool_lock;
   GSList *image_pool;
+
+  gboolean synchronous;
+  gboolean sw_scaling_failed;
+
+  GMutex *nav_lock;
+  GSList *pend_nav_events;
 };
 
 struct _GstXImageSinkClass {
